==> nextcloud-app-bookmarks-1%3A3.1.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/da.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Favoritter",
    "No file provided for import" : "Ingen fil til import",
    "Unsupported file type for import" : "Denne filtype er ikke understøttet til import",
    "A Bookmark manager for Nextcloud" : "En app til at administrere bogmærker i Nextcloud",
    "Select bookmark" : "Vælg bogmærke",
    "Details" : "Detaljer",
    "Rename" : "Omdøb",
    "Move" : "Flyt",
    "Delete" : "Slet",
    "Enter bookmark title" : "Angiv titel på bogmærke",
    "Save" : "Gem",
    "Select one or more tags" : "Vælg et eller flere tags",
    "New folder" : "Ny mappe",
    "Grid view" : "Grid visning",
    "List view" : "Vis som liste",
    "Move selection" : "Flyt valgte",
    "Delete selection" : "Slet valgte",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valgt %n bogmærke","Valgt %n bogmærker"],
    "Enter a link" : "Indtast et link",
    "Create" : "Opret",
    "Cancel" : "Annullér",
    "Enter folder title" : "Angiv folder navn",
    "Public" : "Offentlig",
    "Root folder" : "Rodmappe",
    "_Moving %n folder_::_Moving %n folders_" : ["Flytter %n mappe","Flytter %n mapper"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flytter %n bogmærke","Flytter %n bogmærker"],
    "New Bookmark" : "Nyt Bogmærke",
    "All Bookmarks" : "Alle Bogmærker",
    "Recent Bookmarks" : "Seneste Bokmærker",
    "Untagged" : "Fravalgt",
    "Import" : "Importér",
    "Export" : "Eksportér",
    "Sorting" : "Sortering",
    "Recently added" : "Tilføjet for nylig",
    "Alphabetically" : "Alfabetisk",
    "Most visited" : "Mest besøgte",
    "Last modified" : "Sidst ændret",
    "RSS Feed" : "RSS-strøm",
    "Clear data" : "Fjern data",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Slet alle bogmærker permanent fra din konto. Det kan ikke fortrydes!",
    "Delete all bookmarks" : "Slet alle bogmærker",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName}" : "Tilføj til {instanceName}",
    "Client apps" : "Klient apps",
    "Do you really want to delete all your bookmarks?" : "Ønsker du virkelig at slette alle dine bogmærker?",
    "URL" : "Url",
    "Creation date" : "Oprettelsesdato",
    "Tags" : "Mærker",
    "Notes" : "Noter",
    "Sharing" : "Deling",
    "{time} ago" : "{time} siden",
    "Owner" : "Ejer",
    "Share link" : "Share link",
    "Copy link" : "Kopiér link",
    "Allow editing" : "Tillad redigering",
    "Link copied" : "Link kopieret",
    "Select" : "Vælg",
    "Previews" : "Forhåndsvisning",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Bogmærker kan bruge en tredjepartsteneste til at danne skærmprints af dine bogmærker af hjemmesider",
    "Screeenly" : "Screeenly",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API nøgle",
    "Privacy" : "Privatliv",
    "Performance" : "Ydelse",
    "Failed to load settings" : "Fejl ved indlæsning af indstillinger",
    "Failed to save settings" : "Kunne ikke gemme indstillinger",
    "Add a bookmark" : "Tilføj et bogmærke",
    "This URL is already bookmarked! Overwrite?" : "Denne URL har allerede et bogmærke. Overskriv?",
    "Title" : "Titel",
    "Link" : "Link",
    "Folder" : "Mappe",
    "Failed to find existing bookmark" : "Kunne ikke finde eksisterende bogmærke",
    "Failed to create bookmark" : "Kunne ikke oprette bogmærke",
    "Failed to save bookmark" : "Kunne ikke gemme bogmærke",
    "Failed to move bookmark" : "Kunne ikke flytte bogmærke",
    "Failed to delete bookmark" : "Kunne ikke slette bogmærke",
    "Failed to load tags" : "Kunne ikke indlæse tags.",
    "Failed to load folders" : "Fejl ved indlæsning af mapper",
    "Failed to delete folder" : "Fejl ved sletning af mappe",
    "Failed to create folder" : "Fejl ved opretning af mappe",
    "Failed to move parts of selection" : "Fejl ved flytning af dele af det udvalgte",
    "Failed to delete parts of selection" : "Kan ikke slette dele af det valgte",
    "Failed to fetch bookmarks." : "Fejl ved indlæsning af bogmærker.",
    "Failed to change setting" : "Fejl ved ændring af indstilling",
    "Bookmarks feed" : "Bogmærkestrøm"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3A3.4.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/da.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Favoritter",
    "No file provided for import" : "Ingen fil til import",
    "Unsupported file type for import" : "Denne filtype er ikke understøttet til import",
    "A Bookmark manager for Nextcloud" : "En app til at administrere bogmærker i Nextcloud",
    "Select bookmark" : "Vælg bogmærke",
    "Details" : "Detaljer",
    "Rename" : "Omdøb",
    "Move" : "Flyt",
    "Delete" : "Slet",
    "Select one or more tags" : "Vælg et eller flere tags",
    "New" : "Ny",
    "New folder" : "Ny mappe",
    "Grid view" : "Grid visning",
    "List view" : "Vis som liste",
    "Move selection" : "Flyt valgte",
    "Delete selection" : "Slet valgte",
    "Select all" : "Vælg alle",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valgt %n bogmærke","Valgt %n bogmærker"],
    "Enter a link" : "Indtast et link",
    "Enter folder title" : "Angiv folder navn",
    "Root folder" : "Rodmappe",
    "Cancel" : "Annullér",
    "_Moving %n folder_::_Moving %n folders_" : ["Flytter %n mappe","Flytter %n mapper"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flytter %n bogmærke","Flytter %n bogmærker"],
    "All bookmarks" : "Alle bogmærker",
    "Recent" : "Seneste",
    "Untagged" : "Fravalgt",
    "Add a bookmark" : "Tilføj et bogmærke",
    "Import" : "Importér",
    "Export" : "Eksportér",
    "Sorting" : "Sortering",
    "Recently added" : "Tilføjet for nylig",
    "Alphabetically" : "Alfabetisk",
    "Most visited" : "Mest besøgte",
    "Last modified" : "Sidst ændret",
    "Client apps" : "Klient apps",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName}" : "Tilføj til {instanceName}",
    "Clear data" : "Fjern data",
    "Delete all bookmarks" : "Slet alle bogmærker",
    "Do you really want to delete all your bookmarks?" : "Ønsker du virkelig at slette alle dine bogmærker?",
    "Title" : "Titel",
    "Link" : "Link",
    "Creation date" : "Oprettelsesdato",
    "Tags" : "Mærker",
    "Attachments" : "Vedhæftede filer",
    "Notes" : "Noter",
    "{time} ago" : "{time} siden",
    "Owner" : "Ejer",
    "Sharing" : "Deling",
    "Share link" : "Share link",
    "Copy link" : "Kopiér link",
    "Allow editing" : "Tillad redigering",
    "Link copied" : "Link kopieret",
    "Select" : "Vælg",
    "Previews" : "Forhåndsvisning",
    "Screeenly" : "Screeenly",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API nøgle",
    "Privacy" : "Privatliv",
    "Performance" : "Ydelse",
    "Failed to load settings" : "Fejl ved indlæsning af indstillinger",
    "Failed to save settings" : "Kunne ikke gemme indstillinger",
    "This URL is already bookmarked! Overwrite?" : "Denne URL har allerede et bogmærke. Overskriv?",
    "Enter bookmark title" : "Angiv titel på bogmærke",
    "Folder" : "Mappe",
    "Save" : "Gem",
    "Failed to find existing bookmark" : "Kunne ikke finde eksisterende bogmærke",
    "Failed to create bookmark" : "Kunne ikke oprette bogmærke",
    "Failed to save bookmark" : "Kunne ikke gemme bogmærke",
    "Failed to move bookmark" : "Kunne ikke flytte bogmærke",
    "Failed to delete bookmark" : "Kunne ikke slette bogmærke",
    "Failed to load tags" : "Kunne ikke indlæse tags.",
    "Failed to load folders" : "Fejl ved indlæsning af mapper",
    "Failed to delete folder" : "Fejl ved sletning af mappe",
    "Failed to create folder" : "Fejl ved opretning af mappe",
    "Failed to fetch bookmarks." : "Fejl ved indlæsning af bogmærker.",
    "Failed to change setting" : "Fejl ved ændring af indstilling",
    "Bookmarks feed" : "Bogmærkestrøm"
},
"nplurals=2; plural=(n != 1);");
